@@ -185,7 +185,7 @@ the following order:
 * `on_app_exit`: fired **after* framework win got closed and
   just **before** the event loop of the GUI framework
   will be stopped and the app shutdown.
-* `on_app_quit`: fired **after* the event loop of the GUI framework
+* `on_app_quit`: fired **after** the event loop of the GUI framework
   got stopped and before the :meth:`AppBase.shutdown` method
   will be called.
 
@@ -386,7 +386,7 @@ from ae.files import FilesRegister, RegisteredFile  # type: ignore
 from ae.i18n import default_language                # type: ignore
 
 
-__version__ = '0.0.28'
+__version__ = '0.0.29'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -778,13 +778,16 @@ class MainAppBase(ConsoleApp, ABC):
         :param new_flow_id:     new flow id (maybe overwritten by event handlers in event_kwargs['flow_id']).
         :param popups_to_close: optional sequence of widgets to be closed on confirmed flow change.
         :param event_kwargs:    optional args to pass additional data or info onto and from the event handler.
+
                                 info pass onto event handler:
                                     * `popup_kwargs`: optional dict passed to the Popup `__init__` method,
                                        like e.g. dict(parent=parent_widget_of_popup, data=...).
+
                                 info passed from the event handler:
                                     * `flow_id`: process :attr:`~MainAppBase.flow_path` as specified by the
                                       :paramref:`~change_flow.new_flow_id` argument, but then overwrite this
                                       flow id with this event arg value for to set :attr:`~MainAppBase.flow_id`.
+
         :return:                True if flow changed and got confirmed by a declared custom event handler
                                 (either event method or Popup class) of the app, else False.
                                 Some flow actions are handled internally independent from the
@@ -805,10 +808,11 @@ class MainAppBase(ConsoleApp, ABC):
             return False
 
         has_flow_focus = flow_action(self.flow_id) == 'focus'
+        empty_flow = id_of_flow('', '')
         if action in ACTIONS_EXTENDING_FLOW_PATH:
             self.flow_path.append(new_flow_id)
             self.change_app_state('flow_path', self.flow_path)
-            flow_id = id_of_flow('', '') if action == 'enter' else new_flow_id
+            flow_id = empty_flow if action == 'enter' else new_flow_id
         elif action in ACTIONS_REDUCING_FLOW_PATH:
             # dismiss gets sent sometimes twice (e.g. on heavy double-clicking on drop-down-open-buttons)
             # .. therefore prevent run-time error
@@ -820,9 +824,9 @@ class MainAppBase(ConsoleApp, ABC):
             if action == 'leave':
                 flow_id = replace_flow_action(ended_flow_id, 'focus')
             else:
-                flow_id = self.flow_id if has_flow_focus else id_of_flow('', '')
+                flow_id = self.flow_id if has_flow_focus else empty_flow
         else:
-            flow_id = new_flow_id if action == 'focus' else (self.flow_id if has_flow_focus else id_of_flow('', ''))
+            flow_id = new_flow_id if action == 'focus' else (self.flow_id if has_flow_focus else empty_flow)
 
         popups_to_close = event_kwargs.get('popups_to_close', popups_to_close)
         for widget in reversed(popups_to_close):
@@ -830,7 +834,7 @@ class MainAppBase(ConsoleApp, ABC):
 
         if action not in ACTIONS_REDUCING_FLOW_PATH or not has_flow_focus:
             flow_id = event_kwargs.get('flow_id', flow_id)  # update flow_id from event_kwargs set by event handler
-        if flow_id == id_of_flow('', '') and self._last_focus_flow_id:
+        if flow_id == empty_flow and self._last_focus_flow_id and action not in ACTIONS_EXTENDING_FLOW_PATH:
             flow_id = self._last_focus_flow_id
         self.change_app_state('flow_id', flow_id)
         if flow_action(flow_id) == 'focus':
@@ -977,12 +981,12 @@ class MainAppBase(ConsoleApp, ABC):
                 self.shutdown(self._exit_code or None)  # don't call sys.exit() for zero exit code
 
     def show_popup(self, popup_class: Type, **popup_kwargs) -> Any:
-        """ open Popup by calling `show` method of passed instance.
+        """ open Popup or DropDown by calling `show` method of passed instance.
 
-        Overwrite this method if framework is using different method to open Popup window or if
-        a widget in the Popup need to get the input focus.
+        Overwrite this method if framework is using different method to open popup window or if
+        a widget in the Popup/DropDown need to get the input focus.
 
-        :param popup_class:     class of the Popup widget/window.
+        :param popup_class:     class of the Popup/DropDown widget/window.
         :param popup_kwargs:    args for to instantiate and show/open the popup.
         :return:                created and displayed/opened popup class instance.
         """
